package cn.iocoder.yudao.module.jx.mapper;

import cn.iocoder.yudao.module.jx.domain.DriveSchoolInfo;
import cn.iocoder.yudao.module.jx.vo.DriveSchoolInfoVO;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * 驾校信息Mapper接口
 *
 * @author ruoyi
 * @date 2024-03-19
 */

@Mapper
public interface DriveSchoolInfoMapper
{
    /**
     * 查询驾校信息
     *
     * @param id 驾校信息主键
     * @return 驾校信息
     */
    public DriveSchoolInfo selectDriveSchoolInfoById(Long id);

    /**
     * 查询驾校信息列表
     *
     * @param driveSchoolInfo 驾校信息
     * @return 驾校信息集合
     */
    public IPage<DriveSchoolInfo> selectDriveSchoolInfoList(@Param("entity") DriveSchoolInfo driveSchoolInfo, Page<DriveSchoolInfo> page);

    /**
     * 新增驾校信息
     *
     * @param driveSchoolInfo 驾校信息
     * @return 结果
     */
    public int insertDriveSchoolInfo(DriveSchoolInfo driveSchoolInfo);

    /**
     * 修改驾校信息
     *
     * @param driveSchoolInfo 驾校信息
     * @return 结果
     */
    public int updateDriveSchoolInfo(DriveSchoolInfo driveSchoolInfo);

    /**
     * 删除驾校信息
     *
     * @param id 驾校信息主键
     * @return 结果
     */
    public int deleteDriveSchoolInfoById(Long id);

    /**
     * 批量删除驾校信息
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteDriveSchoolInfoByIds(Long[] ids);

    /**
     * 根据部门ID查询驾校信息
     * @param deptId 部门ID
     * @return  驾校信息
     */
    DriveSchoolInfoVO getSchoolInfoByDeptId(Long deptId);


    /**
     * 根据驾校ID查询驾校信息
     * @param jxId 驾校ID
     * @return  驾校信息
     */
    DriveSchoolInfoVO findInfoByJxId(Long jxId);

}
